package org.fuseri.modulelanguageschool.user;

import jakarta.persistence.*;
import lombok.*;
import org.fuseri.modulelanguageschool.common.DomainObject;
import org.fuseri.modulelanguageschool.course.Course;
import org.fuseri.modulelanguageschool.course.Language;
import org.fuseri.modulelanguageschool.course.ProficiencyLevel;

import java.util.Map;
import java.util.Set;

@Getter
@Setter
@Entity
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = false)
@Table(name = "domain_user")
public class User extends DomainObject {

    private String username;

    @Enumerated(EnumType.STRING)
    private UserType userType;

    private String password;

    private String email;

    private String firstName;

    private String lastName;

    @Embedded
    private Address address;

    @ManyToMany
    @JoinTable(name = "user_course",
            joinColumns = @JoinColumn(name = "student_id"),
            inverseJoinColumns = @JoinColumn(name = "course_id")
    )
    private Set<Course> courses;

    @ElementCollection
    private Map<Language, ProficiencyLevel> languageProficiency;

    public void addLanguageProficiency(Language language, ProficiencyLevel proficiencyLevel) {
        languageProficiency.put(language, proficiencyLevel);
    }
}